@@ -11,20 +11,21 @@
 # All output is in the designated output directory.  Original files are not overwritten.
 ###########################################################################
 
-import os
-import os.path
-from shutil import copyfile
 import argparse
 import collections
+import gzip
+import os
+from shutil import copyfile
 
 from domdiv.tools.common import (
-    get_json_data,
-    load_language_cards,
-    LANGUAGE_XX,
     LANGUAGE_DEFAULT,
+    LANGUAGE_XX,
+    check_compressed_json_change,
+    get_json_data,
     get_languages,
-    multikeysort,
     load_card_data,
+    load_language_cards,
+    multikeysort,
     write_data,
     write_language_cards,
 )
@@ -129,7 +130,7 @@ def main(card_db_dir, output_dir):
     seen = set()
     for c in sorted_card_data:
         if c["card_tag"] in seen:
-            assert False, f"Duplicate card detected: {c['card_tag']}"
+            raise RuntimeError(f"Duplicate card detected: {c['card_tag']}")
         seen.add(c["card_tag"])
     groups = set(card["group_tag"] for card in sorted_card_data if "group_tag" in card)
     super_groups = set(["events", "landmarks", "projects"])
@@ -276,12 +277,18 @@ def main(card_db_dir, output_dir):
         if lang == LANGUAGE_XX:
             fromLanguage = LANGUAGE_DEFAULT
 
-        copyfile(
-            os.path.join(
-                card_db_dir, fromLanguage, "bonuses_" + fromLanguage + ".json"
-            ),
-            os.path.join(output_dir, lang, "bonuses_" + lang + ".json"),
-        )
+        with open(
+            os.path.join(card_db_dir, fromLanguage, "bonuses_" + fromLanguage + ".json")
+        ) as f:
+            data = f.read()
+            output_fname = os.path.join(output_dir, lang, f"bonuses_{lang}.json.gz")
+            if check_compressed_json_change(output_fname, data):
+                with gzip.open(
+                    output_fname,
+                    "wt",
+                    encoding="utf-8",
+                ) as fout:
+                    fout.write(data)
 
     ###########################################################################
     # translation.txt
